@@ -789,7 +789,7 @@ populate_target(std::string& target, char *arg) {
 		else
 			perror("Failed to expand target");
 
-		free(x);		
+		free(x);
 	} else {
 		perror("Failed to generate target");
 	}
@@ -917,6 +917,7 @@ static const struct fuse_opt btfs_opts[] = {
 	BTFS_OPT("--browse-only",                browse_only,          1),
 	BTFS_OPT("-k",                           keep,                 1),
 	BTFS_OPT("--keep",                       keep,                 1),
+	BTFS_OPT("--data-directory=%s",          data_directory,       4),
 	BTFS_OPT("--min-port=%lu",               min_port,             4),
 	BTFS_OPT("--max-port=%lu",               max_port,             4),
 	BTFS_OPT("--max-download-rate=%lu",      max_download_rate,    4),
@@ -952,6 +953,7 @@ print_help() {
 	printf("    --help-fuse            print all fuse options\n");
 	printf("    --browse-only -b       download metadata only\n");
 	printf("    --keep -k              keep files after unmount\n");
+	printf("    --data-directory=dir   directory in which to put btfs data\n");
 	printf("    --min-port=N           start of listen port range\n");
 	printf("    --max-port=N           end of listen port range\n");
 	printf("    --max-download-rate=N  max download rate (in kB/s)\n");
@@ -1022,7 +1024,7 @@ main(int argc, char *argv[]) {
 
 	std::string target;
 
-	if (!populate_target(target, NULL))
+	if (!populate_target(target, params.data_directory))
 		return -1;
 
 	libtorrent::add_torrent_params p;
